==> kagetaka-src-0.2.tar.gz: kagetaka-0.2/src/net/hizlab/kagetaka/viewer/ViewerConsole.java <==
/* ----- BEGIN LICENSE BLOCK -----
 * Version: MPL 1.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the Kagetaka Libraries.
 *
 * The Initial Developer of the Original Code is Hizuya Atsuzaki
 * Portions created by the Initial Developer are Copyright (C) 2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s): Hizuya Atsuzaki <hizuya@hizlab.net>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ----- END LICENSE BLOCK ----- */
package net.hizlab.kagetaka.viewer;

import net.hizlab.kagetaka.Reporter;

/**
 * 륳󥽡Ǥ
 * 
 * @author  <A HREF="mailto:hizuya@hizlab.net">Hizuya Atsuzaki</A>
 * @version $Revision: 1.2 $
 */
class ViewerConsole
{
	private ViewerReporter reporter;
	
	private ViewerOption option;
	
	/** 󥹥󥹤 */
	ViewerConsole(ViewerOption option)
	{
		this.option   = option;
		this.reporter = new ViewerReporter();
	}
	
	/** ݡ */
	Reporter getReporter()
	{
		return reporter;
	}
	
//### ViewerReporter
	/** 륦ɥѤΥݡ */
	private class ViewerReporter
		implements Reporter
	{
		/** 󥹥󥹤 */
		private ViewerReporter()
		{
		}
		
		/** 륦ɥѤΥݡ */
		public void report(int level, String message, int line, int column)
		{
			if (level < option.getLogLevel())
				return;
			
			StringBuffer sb = new StringBuffer();
			sb.append("#");
			
			switch (level) {
			case Reporter.ERROR  : sb.append("ERROR"  ); break;
			case Reporter.WARNING: sb.append("WARNING"); break;
			default: sb.append("MESSAGE");
			}
			
			sb.append(":");
			sb.append(line);
			sb.append(":");
			sb.append(column);
			sb.append(":");
			sb.append(message);
			System.out.println(sb.toString());
		}
		
		/** Υå٥֤ */
		public int getLevel()
		{
			return option.getLogLevel();
		}
	}
}

==> kagetaka-src-0.3.1.tar.gz: kagetaka-0.3.1/src/net/hizlab/kagetaka/viewer/ViewerConsole.java <==
/* ----- BEGIN LICENSE BLOCK -----
 * Version: MPL 1.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the Kagetaka Libraries.
 *
 * The Initial Developer of the Original Code is Hizuya Atsuzaki
 * Portions created by the Initial Developer are Copyright (C) 2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s): Hizuya Atsuzaki <hizuya@hizlab.net>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ----- END LICENSE BLOCK ----- */
package net.hizlab.kagetaka.viewer;

import net.hizlab.kagetaka.Reporter;
import net.hizlab.kagetaka.option.ViewerOption;

/**
 * 륳󥽡Ǥ
 * 
 * @author  <A HREF="mailto:hizuya@hizlab.net">Hizuya Atsuzaki</A>
 * @version $Revision: 1.3 $
 */
public class ViewerConsole
{
	private ViewerReporter reporter;
	
	private ViewerOption option;
	private int          currentLevel;
	
	/**
	 * 륳󥽡ޤ
	 * 
	 * @param     option ץ
	 */
	public ViewerConsole(ViewerOption option)
	{
		this.option       = option;
		this.reporter     = new ViewerReporter();
		this.currentLevel = option.getPropertyInteger(ViewerOption.KEY_LOG_LEVEL, Reporter.ERROR);
	}
	
	/** ݡ */
	Reporter getReporter()
	{
		return reporter;
	}
	
//### ViewerReporter
	/** 륦ɥѤΥݡ */
	private class ViewerReporter
		implements Reporter
	{
		/** 󥹥󥹤 */
		private ViewerReporter()
		{
		}
		
		/** 륦ɥѤΥݡ */
		public void report(int level, String message, int line, int column)
		{
			if (level < currentLevel)
				return;
			
			StringBuffer sb = new StringBuffer();
			sb.append("#");
			
			switch (level) {
			case Reporter.ERROR  : sb.append("ERROR"  ); break;
			case Reporter.WARNING: sb.append("WARNING"); break;
			default: sb.append("MESSAGE");
			}
			
			sb.append(":");
			sb.append(line);
			sb.append(":");
			sb.append(column);
			sb.append(":");
			sb.append(message);
			System.out.println(sb.toString());
		}
		
		/** Υå٥֤ */
		public int getLevel()
		{
			return currentLevel;
		}
	}
}
